@@ -1,8 +1,8 @@
 /*
     constants.h : espctag
-    v0.3 - 2011-09-19
+    v0.4 - 2012-08-29
     
-    Copyright (C) 2011 Jérôme SONRIER <jsid@emor3j.fr.eu.org>
+    Copyright (C) 2011,2012 Jérôme SONRIER <jsid@emor3j.fr.eu.org>
 
     This file is part of espctag.
 
@@ -20,6 +20,8 @@
     along with espctag.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#define MAX_FILENAME_LENGTH 4096
+
 /* Tags index */
 #define I_SONG_TITLE  0
 #define I_GAME_TITLE  1
@@ -33,6 +35,15 @@
 #define I_EMULATOR    9
 
 /* Return codes */
-#define SUCCESS 0
-#define E_WRONG_ARG -100
-#define E_OPEN_FILE -200
+#define SUCCESS          0
+#define E_WRONG_ARG   -100
+#define E_OPEN_FILE   -200
+#define E_RENAME_FILE -201
+#define E_CREATE_DIR  -202
+#define E_OPEN_DIR    -203
+#define E_CH_DIR      -204
+#define E_DEL_DIR     -205
+#define E_DEL_FILE    -206
+#define E_FORK        -300
+#define E_PACK_RSN    -400
+#define E_UNPACK_RSN  -401
